@@ -15,8 +15,6 @@ use std::mem;
 #[cfg(feature = "sql")]
 use crate::SqlConversionError;
 
-use std::convert::TryFrom;
-
 #[derive(Debug, Clone, PartialEq, PartialOrd)]
 #[non_exhaustive]
 /// A simple structure to hold address information
@@ -73,6 +71,20 @@ impl Address {
 }
 
 impl Geo {
+    /// Creates a `Geo` from longitue and latitude.
+    ///
+    /// Both are floats and are given in the order `lontigude`
+    /// and `latitude`.
+    ///
+    /// # Examples
+    ///
+    /// Create a new `Geo` at null island.
+    ///
+    /// ```rust
+    /// use contack::Geo;
+    /// let geo = Geo::new(0.0, 0.0);
+    /// ```
+    ///
     #[must_use]
     pub const fn new(longitude: f64, latitude: f64) -> Self {
         Self {
@@ -130,7 +142,7 @@ impl AddressRaw {
 
 #[cfg(feature = "sql")]
 impl Address {
-    /// Converts an address to something that can be used by a SqlContact.
+    /// Converts an address to something that can be used by a `SqlContact`.
     pub(crate) fn to_sql_raw(address: Option<Self>) -> AddressRawTuple {
         match address {
             None => (None, None, None, None, None, (None, None)),
@@ -152,9 +164,13 @@ impl Address {
 #[cfg(feature = "sql")]
 impl AddressRaw {
     /// This should only be used internally.
+    ///
+    /// # Errors
+    ///
+    /// Fails if given an imcomplete geo, requires both
+    /// `longitude` and `latitude`.
     pub(crate) fn try_from_sql_raw(
         self,
-        field_name: &'static str,
     ) -> Result<Option<Address>, SqlConversionError> {
         let address = Address {
             // Set up the basic fields
@@ -166,38 +182,13 @@ impl AddressRaw {
 
             // Set up the Geo
             geo: {
-                // Checks if the Geo is none
-                if self.geo_long.is_none() && self.geo_lat.is_none() {
-                    None
-                } else {
-                    // Otherwise make sure that it is some.
-                    if self.geo_long.is_some() {
-                        if self.geo_lat.is_some() {
-                            // Creates the Geo
-                            Some(Geo::new(
-                                self.geo_long.unwrap(),
-                                self.geo_lat.unwrap(),
-                            ))
-                        } else {
-                            return Err(SqlConversionError::InvalidProperty(
-                                format!(
-                                    "Incomplete Geo in {}, \
-                                            missing latitude",
-                                    field_name
-                                ),
-                            ));
-                        }
-                    } else if self.geo_lat.is_some() {
-                        return Err(SqlConversionError::InvalidProperty(
-                            format!(
-                                "Incomplete Geo in {}, \
-                                            missing longitude",
-                                field_name
-                            ),
-                        ));
-                    } else {
-                        None
-                    }
+                match (self.geo_long, self.geo_lat) {
+                    (Some(longitude), Some(latitude)) => Some(Geo {
+                        longitude,
+                        latitude,
+                    }),
+                    (None, None) => None,
+                    _ => return Err(SqlConversionError::IncompleteGeo),
                 }
             },
         };
