@@ -1,11 +1,15 @@
-//! # Escape
-//!
 //! These are functions todo with escaping the VCard properties.
+//!
+//! None of these need to be called directly.
 
 use std::collections::HashMap;
 use std::ops::Deref;
 
 /// This will fold a line. This is run when generating a component.
+///
+/// Line folding requires that every 80 octets the line
+/// is folded. Unforunately that is a pain to do
+/// so I just to it every 75 unichars.
 pub fn fold_line<T>(string: T) -> String
 where
     T: Deref<Target = str>,
@@ -23,6 +27,10 @@ where
 }
 
 /// This will unfold a line. This is run when generating a component.
+///
+/// This implementation is not as good as it should be.
+/// See issue
+/// [#1](https://gitlab.com/john_t/contack/-/issues/8)
 pub fn unfold_line<T>(string: T) -> String
 where
     T: Deref<Target = str>,
@@ -36,10 +44,10 @@ where
     T: Deref<Target = str>,
 {
     string
-        .replace("\\", "\\\\")
-        .replace(",", "\\,")
-        .replace(";", "\\;")
-        .replace("\n", "\\n")
+        .replace('\\', "\\\\")
+        .replace(',', "\\,")
+        .replace(';', "\\;")
+        .replace('\n', "\\n")
 }
 
 /// This will unescape a property
@@ -54,7 +62,7 @@ where
         .replace("\\\\", "\\")
 }
 
-// This will get all the parameters from a string of parameters.
+/// This will get all the parameters from a string of parameters.
 #[must_use]
 pub fn get_parameters(mut string: String) -> HashMap<String, String> {
     string.push(';');
@@ -103,7 +111,7 @@ pub fn get_parameters(mut string: String) -> HashMap<String, String> {
     map
 }
 
-// This will get all the values in a string.
+/// This will get all the values in a string.
 #[must_use]
 pub fn get_values(mut string: String) -> Vec<Vec<String>> {
     string = string.trim().to_string();
@@ -135,7 +143,7 @@ pub fn get_values(mut string: String) -> Vec<Vec<String>> {
                     ';' => strings.push(vec![String::new()]),
                     ',' => {
                         if let Some(active_val) = strings.last_mut() {
-                            active_val.push(String::new())
+                            active_val.push(String::new());
                         }
                     }
                     _ => active_string.push(i),
