@@ -1,8 +1,11 @@
+//! Struct for representing contact information.
+
 #[cfg(feature = "diesel_support")]
 use crate::schema::*;
 use crate::*;
-use std::convert::TryInto;
 
+/// Represents contact information as it should appear
+/// in sql.
 #[cfg_attr(
     feature = "diesel_support",
     derive(Queryable, Identifiable, Insertable, AsChangeset),
@@ -11,7 +14,8 @@ use std::convert::TryInto;
 )]
 #[cfg_attr(feature = "sqlx", derive(sqlx::FromRow))]
 pub struct SqlContactInformation {
-    // The pid, used for representing this
+    /// The pid, used for representing this. Should be
+    /// unique.
     pub pid: String,
 
     /// The Preference Value
@@ -31,6 +35,8 @@ pub struct SqlContactInformation {
 }
 
 impl SqlContactInformation {
+    /// Empties contact information from a contact.
+    ///
     /// Extracts, by means of emptying the contact information in a contact,
     /// the contact information so that it can be used by diesel. Later,
     /// use `insert_contact_information` to replace it back.
@@ -39,13 +45,14 @@ impl SqlContactInformation {
     /// cloned for these structs to work :/.
     #[must_use]
     pub fn extract_contact_information(contact: &mut Contact) -> Vec<Self> {
+        let uid = contact.uid.clone();
         // Get the contact information, replacing it with an empty vec.
-        let ci: Vec<ContactInformation> =
-            contact.contact_information.drain(..).collect();
+        let ci =
+            contact.contact_information.drain(..);
 
         // Loop through everything in the contact information.
-        ci.into_iter()
-            .map(|x| Self::convert_from(x, contact.uid.clone()))
+        ci
+            .map(|x| Self::convert_from(x, uid.clone()))
             .collect()
     }
 
@@ -63,11 +70,11 @@ impl SqlContactInformation {
     }
 
     /// Add contact information to a contact based of a vec of
-    /// ContactInformation.
+    /// `ContactInformation`.
     pub fn insert_contact_information(ci: Vec<Self>, contact: &mut Contact) {
         contact
             .contact_information
-            .append(&mut ci.into_iter().map(|x| x.into()).collect());
+            .append(&mut ci.into_iter().map(Into::into).collect());
     }
 }
 
