@@ -6,13 +6,25 @@ use crate::read_write::error::FromComponentError;
 use crate::SqlConversionError;
 #[cfg(feature = "read_write")]
 use regex::Regex;
-use std::convert::TryFrom;
 
 /// A struct which can either store byte information or a url
 #[derive(Debug, Clone, Eq, PartialEq, Ord, PartialOrd)]
 pub enum Uri {
-    Url { url: String },
-    Bytes { val: Vec<u8>, mime: String },
+    /// Represents a classic url of any type.
+    Url {
+        /// A url/uri, such as <http://www.example.com>
+        url: String
+    },
+    /// Used (for ease of use) to represent binary data,
+    /// will be encoded as base64, and will attempt
+    /// to be decoded as such aswell.
+    Bytes {
+        /// The bytes that make up the value, ie the
+        /// contents of a png file.
+        val: Vec<u8>,
+        /// The mimetype, ie "image/png"
+        mime: String
+    },
 }
 
 impl Uri {
@@ -48,8 +60,11 @@ impl Uri {
     /// This should only be used internally.
     ///
     /// The first `Option<String>` is the url, the `Option<Vec<u8>>` a binary
-    /// value and the final `Option<String>` is the mime. The last `String` is
-    /// for path, when given an error.
+    /// value and the final `Option<String>` is the mime.
+    ///
+    /// # Errors
+    ///
+    /// Fails with an incomplete binary.
     pub fn try_from_sql_raw(
         tup: (Option<String>, Option<Vec<u8>>, Option<String>, String),
     ) -> Result<Option<Self>, SqlConversionError> {
@@ -58,25 +73,10 @@ impl Uri {
             Some(val) => Ok(Some(Self::new_url(val))),
 
             // Binary Type
-            None => match tup.1 {
-                Some(bin) => match tup.2 {
-                    Some(mime) => Ok(Some(Self::new_bytes(bin, mime))),
-                    None => Err(SqlConversionError::InvalidProperty(format!(
-                        "{3}(Uri) {} is set to null, \n\
-                            but {3}(Uri) {} has the value of {:#?}. A Uri url value has also not been \n\
-                            given and so the enum is invalid.",
-                        "mime", "bin", bin, tup.3
-                    ))),
-                },
-                None => match tup.2 {
-                    None => Ok(None),
-                    Some(mime) => Err(SqlConversionError::InvalidProperty(format!(
-                        "{3}(Uri) {} is set to null, \n\
-                            but {3}(Uri) {} has the value of {:#?}. A Uri url value has also not been \n\
-                            given and so the enum is invalid.",
-                        "bin", "mime", mime, tup.3
-                    ))),
-                },
+            None => match (tup.1, tup.2) {
+                (Some(bin), Some(mime)) => Ok(Some(Self::new_bytes(bin, mime))),
+                (None, None) => Ok(None),
+                _ => Err(SqlConversionError::IncompleteUri),
             },
         }
     }
