@@ -3,7 +3,6 @@ use contack::read_write::component::Component;
 use contack::read_write::escape;
 use contack::read_write::vcard::VCard;
 use contack::*;
-use std::convert::{TryFrom, TryInto};
 use std::error::Error;
 
 #[test]
@@ -96,3 +95,36 @@ fn to_from_test() -> Result<(), Box<dyn Error>> {
 
     Ok(())
 }
+
+#[test]
+fn multi_vcard() {
+    let vcard = include_str!("multi_vcard.vcf");
+    let vcards: Vec<VCard> = VCard::from_str_to_vec(&vcard).unwrap();
+    let mut contacts: Vec<Contact> = Vec::with_capacity(vcards.len());
+    for vcard in vcards {
+        contacts.push(vcard.try_into().unwrap())
+    }
+    assert_eq!(
+        contacts,
+        vec![
+            Contact {
+                uid: "7917f88b-c095-4226-b11b-433c4aea5feb".to_string(),
+                name: contack::Name {
+                    given: Some("John".to_string()),
+                    family: Some("Doe".to_string()),
+                    ..Default::default()
+                },
+                ..Contact::new(contack::Name::default())
+            },
+            Contact {
+                uid: "83bd5b1e-7b9c-4067-9e0c-d8e187dc521e".to_string(),
+                name: contack::Name {
+                    given: Some("Anne".to_string()),
+                    family: Some("Parker".to_string()),
+                    ..Default::default()
+                },
+                ..Contact::new(contack::Name::default())
+            }
+        ]
+    )
+}
